Readers and Writers
===================

.. automodule:: audiotsm.io

Numpy arrays
------------

.. automodule:: audiotsm.io.array
    :members:
    :show-inheritance:

Wav files
---------

.. automodule:: audiotsm.io.wav
    :members:
    :show-inheritance:

Play in real-time
-----------------

.. automodule:: audiotsm.io.stream
    :members:
    :show-inheritance:

Implementing your own
---------------------

.. automodule:: audiotsm.io.base
    :members:
    :undoc-members:
